package com.himajin2001.marubatsu.player;

import java.util.Random;

import com.himajin2001.marubatsu.board.STONE;
import com.himajin2001.marubatsu.control.Position;


/**
 * Playerのダミー実装
 * 
 * @author tsubasa
 */
public class DummyPlayer implements IPlayer {

	private int width = 0;

	private int hight = 0;

	private Random random;

	private STONE stone = null;

	/**
	 * デフォルトコンストラクタ。
	 * 
	 * IPlayerでは必要。
	 */
	public DummyPlayer() {
		// 乱数の初期化
		this.random = new Random(System.currentTimeMillis());
	}

	/**
	 * 対戦者の名前「乱数ロボット1号」
	 * 
	 * @see com.himajin2001.marubatsu.player.IPlayer#getName()
	 */
	@Override
	public String getName() {
		return "乱数ロボット1型";
	}

	/**
	 * 対戦盤面の高さを設定する。
	 * 
	 * ゲーム側から呼ばれる。
	 * 
	 * @see com.himajin2001.marubatsu.player.IPlayer#setHight(int)
	 */
	@Override
	public void setHight(int hight) {
		this.hight = hight;
	}

	/**
	 * 対戦盤面の幅を設定する。
	 * 
	 * ゲーム側から呼ばれる。
	 * 
	 * @see com.himajin2001.marubatsu.player.IPlayer#setWidth(int)
	 */
	@Override
	public void setWidth(int width) {
		this.width = width;
	}

	/**
	 * 先攻・後攻情報をセットする。
	 * 
	 * ゲーム側から呼ばれる。
	 * 
	 * @see com.himajin2001.marubatsu.player.IPlayer#setStone(com.himajin2001.marubatsu.board.STONE)
	 */
	@Override
	public void setStone(STONE stone) {
		this.stone = stone;
	}

	/**
	 * どこに石を置くか考える。
	 * 
	 * 空いている枡にランダムで置いているだけ…。
	 * 
	 * @see com.himajin2001.marubatsu.player.IPlayer#think(com.himajin2001.marubatsu.board.STONE[][])
	 */
	@Override
	public Position think(STONE[][] hexes) throws Exception {
		this.stone.toString(); // 警告をかわすためのダミー
		int x, y;
		do {
			x = this.random.nextInt(this.width);
			y = this.random.nextInt(this.hight);
		} while (hexes[y][x] != STONE.BLANK);

		Position pos = new Position(y, x);

		return pos;
	}
}
